Skip to contents

Integrates concepts of stochastic demography into species distribution modelling. The main approach maximizes a likelihood function based on environmental information and presence/absence records. This is used to reconstruct species' fundamental ecological niches and to project their potential geographic range. Data requirements include species presence/absence records and a timeseries of environmental data.

See also

Author

Maintainer: Angel Luis Robles Fernandez a.l.robles.fernandez@gmail.com (ORCID)

Authors: