Compute likelihood for LTSG model
like_ltsg.RdCompute likelihood for LTSG model
Compute likelihood for LTSG model
Arguments
- mu
Numeric vector of means (length equal to number of rows in `env_m`)
- env_m
Numeric matrix of environmental data. Must be column-major with time varying fastest: column
jcorresponds to(location, time)via indexj*q + i. This matches the memory layout expected by the underlying C++ implementation.- dl_mat
Diagonal matrix (as NumericMatrix)
- drl_mat
Diagonal matrix (as NumericMatrix)
- ortho_m
Numeric matrix (orthogonal basis)
- q
Integer, number of rows for reshaping
- r
Integer, number of columns for reshaping.
Value
A numeric vector of length `r` with computed sums.
A numeric vector of length `r` with computed sums.
Details
This function calculates a likelihood-like measure using orthogonal matrices, environmental data, and diagonal matrices, leveraging parallel computation.
This function calculates a likelihood-like measure using orthogonal matrices, environmental data, and diagonal matrices, leveraging parallel computation.