Function to facilitate the creation of the argument mask to the function loglik_math
make_mask_names.RdThe argument mask to the function loglik_math is required to
follow some very specific conventions in order to reduce the risk of errors
coming from mismatched arguments. This function facilitates the creation of
such vectors.
Value
A named numeric vector full of NAs, with the names generated according
to the conventions in Details of the function loglik_math. See also Details
below.