xsdm: Demographic Approach to Species Distribution Model
xsdm-package.RdIntegrates concepts of stochastic demography into species distribution modelling. The main approach maximizes a likelihood function based on environmental information and presence/absence records. This is used to reconstruct species' fundamental ecological niches and to project their potential geographic range. Data requirements include species presence/absence records and a timeseries of environmental data.
Author
Maintainer: Angel Luis Robles Fernandez a.l.robles.fernandez@gmail.com (ORCID)
Authors:
Emilio Berti emilio.berti@idiv.de (ORCID)
Daniel C. Reuman reuman@ku.edu (ORCID)